==> mx-codecs_23.7.02.tar.xz: mx-codecs/translations/mx-codecs_fil_PH.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fil_PH">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>Installer ng MX Codecs </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Sa application na ito maari mong mainstall ang mga hindi pinapayagang codec para sa pag-papaandar ng vido at audio &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt; Sa ilang mga larangan ay maaring may limitasyon. Mangaring tiyakin muna ang panuntunan sa iyong lugar. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt; Nananagutan ka ba sa pagda-download nitong mga codecs na ito?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Nagda-download ng mga files ng codecs </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Cancel any changes then quit</source>
        <translation>Huwag tanggapin ang mga binago at lumabas na</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Cancel</source>
        <translation>I-cancel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Begin codec download and installation</source>
        <translation>Pasimulan ang pagda-download ng codec at pag-iinstall</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>About this application</source>
        <translation>Patungkol sa application na ito</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>About...</source>
        <translation>Patungkol sa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Display help </source>
        <translation>Maghanap ng tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Help</source>
        <translation>Tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Umaandar ang command na...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="151"/>
        <location filename="../mainwindow.cpp" line="171"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Error</source>
        <translation>May error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Cannot connect to the download site</source>
        <translation>Di makakonecta sa pagina na pinagda-downloadan </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Error downloading %1</source>
        <translation>May error sa pagda-download %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>downloading Packages.gz from &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>downloading Packages.gz from &apos;non-free&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>downloading Packages.gz from i386 &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tapos na pagda-download.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Cannot connect find %1 package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Installing downloaded files</source>
        <translation>Kasalukuyang ini-install ang mga na-downloaded na files</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Wala mga na-downloaded na *.debs file na matatagpuan. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Nag-iinstall...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Error installing %1</source>
        <translation>May error sa pag-iinstalling %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Fix missing dependencies...</source>
        <translation>Inaayos ang mga nawawalang dependencies...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Error running %1 command</source>
        <translation>May error sa pagpapa-andar ng  command na %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tapos na ang proseso ng pag-iinstall&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Finished</source>
        <translation>Tapos na</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Ang mga files ng code ay matagumpay na nai-download at nai-install.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Tapos na ang proseso. Nagkaroon ng mga errors samantalang nag-iinstall.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>About MX Codecs</source>
        <translation>Patungkol sa mga MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MX Codecs</source>
        <translation type="vanished">MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Version: </source>
        <translation>Bersyon: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Simpleng pang-download ng codecs para sa MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Karapatan (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Lisensya</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Ulat na mga pagbabago</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Lumabas</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to get exclusive lock</source>
        <translation type="vanished">Di maaring makakuha ng eksclusibong pansara</translation>
    </message>
    <message>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="vanished">May iba pang package management application (tulad ng Synaptic o apt-get), ang kasalukuyang umaandar. Kailangan munang patayin ang mga application na yaon</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Dapat paandaring ang program na ito bilang root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Lisensya</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation type="unfinished">Ulat na mga pagbabago</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation type="unfinished">I-cancel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Lumabas</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished">May error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished">Di maaring makakuha ng eksclusibong pansara</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished">May iba pang package management application (tulad ng Synaptic o apt-get), ang kasalukuyang umaandar. Kailangan munang patayin ang mga application na yaon</translation>
    </message>
</context>
</TS>

==> mx-codecs_23.7.03.tar.xz: mx-codecs/translations/mx-codecs_fil_PH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="fil_PH">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>Installer ng MX Codecs </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Sa application na ito maari mong mainstall ang mga hindi pinapayagang codec para sa pag-papaandar ng vido at audio &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt; Sa ilang mga larangan ay maaring may limitasyon. Mangaring tiyakin muna ang panuntunan sa iyong lugar. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt; Nananagutan ka ba sa pagda-download nitong mga codecs na ito?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Nagda-download ng mga files ng codecs </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Huwag tanggapin ang mga binago at lumabas na</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Cancel</source>
        <translation>I-cancel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Begin codec download and installation</source>
        <translation>Pasimulan ang pagda-download ng codec at pag-iinstall</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>Patungkol sa application na ito</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>Patungkol sa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>Display help </source>
        <translation>Maghanap ng tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Help</source>
        <translation>Tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <location filename="../mainwindow.cpp" line="112"/>
        <location filename="../mainwindow.cpp" line="120"/>
        <location filename="../mainwindow.cpp" line="128"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="153"/>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Umaandar ang command na...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="146"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="164"/>
        <location filename="../mainwindow.cpp" line="193"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>Error</source>
        <translation>May error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Cannot connect to the download site</source>
        <translation>Di makakonecta sa pagina na pinagda-downloadan </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="132"/>
        <location filename="../mainwindow.cpp" line="147"/>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>Error downloading %1</source>
        <translation>May error sa pagda-download %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tapos na pagda-download.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Installing downloaded files</source>
        <translation>Kasalukuyang ini-install ang mga na-downloaded na files</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="194"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Wala mga na-downloaded na *.debs file na matatagpuan. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Nag-iinstall...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="220"/>
        <source>Error installing %1</source>
        <translation>May error sa pag-iinstalling %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Fix missing dependencies...</source>
        <translation>Inaayos ang mga nawawalang dependencies...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Error running %1 command</source>
        <translation>May error sa pagpapa-andar ng  command na %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tapos na ang proseso ng pag-iinstall&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Finished</source>
        <translation>Tapos na</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Ang mga files ng code ay matagumpay na nai-download at nai-install.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Tapos na ang proseso. Nagkaroon ng mga errors samantalang nag-iinstall.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>About MX Codecs</source>
        <translation>Patungkol sa mga MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>MX Codecs</source>
        <translation>MX Codecs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Version: </source>
        <translation>Bersyon: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Simpleng pang-download ng codecs para sa MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Karapatan (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>License</source>
        <translation>Lisensya</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Changelog</source>
        <translation>Ulat na mga pagbabago</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>&amp;Lumabas</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Di maaring makakuha ng eksclusibong pansara</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>May iba pang package management application (tulad ng Synaptic o apt-get), ang kasalukuyang umaandar. Kailangan munang patayin ang mga application na yaon</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Dapat paandaring ang program na ito bilang root.</translation>
    </message>
</context>
</TS>
